package BPpackage;

import android.app.Activity;
import android.app.ListActivity;
import android.os.Bundle;
import android.os.Handler;
import android.view.Gravity;
import android.view.inputmethod.InputMethodManager;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.Toast;
import java.lang.Runnable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import BPpackage.glossary.*;


public class Glossary extends ListActivity {

	public InputMethodManager imm;
	public Map<String, ArrayList<GlossaryEntry>> dbs = 
		new HashMap<String, ArrayList<GlossaryEntry>>();
	public PRAFileHandler fhandler = new PRAFileHandler(this);
	public ImageButton search;
	public EditText term;
	public EdgeEffectListView listView;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		imm = (InputMethodManager) getSystemService(Activity.INPUT_METHOD_SERVICE);
		setContentView(R.layout.activity_glossary);
		search = (ImageButton) findViewById(R.id.search);
		term = (EditText) findViewById(R.id.term);
		buildDict();
		
	}


	private void buildDict() {
		String[] db = fhandler.getAssetAsArray("ruzhechu.db");
		String[] tokens = null;
		GlossaryEntry tmp = null;
		String key = null;
		for (String e : db) {
			while (e.contains("\t\t")){
				e = e.replace("\t\t", "\t");
			}
			tokens = e.split("\t");
			String def = tokens[4];
			def = def.replace("_", " ");
			tmp = new GlossaryEntry( tokens[1], tokens[3], tokens[2], def );
			key = tokens[3].replaceAll("[1-5]", "");
			if (dbs.containsKey(key)){
				dbs.get(key).add(tmp);
			} else {
				ArrayList<GlossaryEntry> atmp = new ArrayList<GlossaryEntry>();
				atmp.add(tmp);
				dbs.put(key, atmp);
			}
		}
	}


	public void toaster(String text, int length) {
		Toast t = Toast.makeText(this, text, length);
		t.setGravity(Gravity.CENTER, 0, 0);
		t.show();
	}


    public void search(View view){
		String query = term.getText().toString();
		//		if (query.matches("")){ return; }
		final GlossaryEntry[] list = buildList(query);
		listView = (EdgeEffectListView) getListView();
		DictAdapter adapter = new DictAdapter(this, R.layout.glossary_entry, list);		
        listView.setAdapter(adapter);
		adapter.notifyDataSetChanged();
		term.setText("");
		imm.toggleSoftInput(InputMethodManager.HIDE_IMPLICIT_ONLY, 0);    
	}


	private GlossaryEntry[] buildList(String term) {
		List<GlossaryEntry> alist = new ArrayList<GlossaryEntry>();
		String[] keys = dbs.keySet().toArray(new String[0]);		
		ArrayList<GlossaryEntry> atmp = null;
		for (String k : keys) {
			if (k.startsWith(term)){
				atmp = dbs.get(k);
				for (GlossaryEntry a : atmp){
					alist.add(a);
				}
			}
		}

		GlossaryEntry[] list = new GlossaryEntry[alist.size()];
		alist.toArray(list);
		return list;
	}


	private boolean doubleBackPressedOnce = false;

	@Override
	public void onBackPressed() {
		if (doubleBackPressedOnce) {
			super.onBackPressed();
			return;
		}
		doubleBackPressedOnce = true;
		Toast.makeText(this, R.string.exit_bkbtn, Toast.LENGTH_SHORT).show();
		new Handler().postDelayed(new Runnable() {

			@Override
			public void run() {
				doubleBackPressedOnce = false;
			}
		}, 2000);
	}

}
